LimitStore

Struct LimitStore 

pub struct LimitStore<T: ObjectStore> { /* private fields */ }
Store wrapper that wraps an inner store and limits the maximum number of concurrent object store operations. Where each call to an ObjectStore member function is considered a single operation, even if it may result in more than one network call


// Create an in-memory `ObjectStore` limited to 20 concurrent requests
let store = LimitStore::new(InMemory::new(), 20);

Implementations

Source

impl<T: ObjectStore> LimitStore<T>

pub fn new(inner: T, max_requests: usize) -> Self

Create new limit store that will limit the maximum number of outstanding concurrent requests to max_requests